@@ -7,6 +7,7 @@
 =end
 
 require 'enumerator'
+require "net/http"
 
 require 'plist'
 
@@ -19,6 +20,7 @@ module Vpim
   # Currently supported repository types are:
   # - Repo::Apple3, an Apple iCal3 repository.
   # - Repo::Directory, a directory hierarchy containing .ics files
+  # - Repo::Uri, a URI that identifies a single iCalendar
   #
   # All repository types support at least the methods of Repo, and all
   # repositories return calendars that support at least the methods of
@@ -79,7 +81,9 @@ module Vpim
           return Enumerable::Enumerator.new(self, :each, klass)
         end
 
-        cals = Vpim::Icalendar.decode(File.open(file))
+        cals = open(file) do |io|
+          Vpim::Icalendar.decode(io)
+        end
 
         cals.each do |cal|
           cal.each(klass, &block)
@@ -176,6 +180,82 @@ module Vpim
         self
       end
     end
+
+    class Uri < Repo
+      def self.uri_check(uri)
+        uri = case uri
+               when URI
+                 uri
+               else
+                 begin
+                   URI.parse(uri)
+                 rescue URI::InvalidURIError => e
+                   raise ArgumentError, "Invalid URI for #{uri.inspect} - #{e.to_s}"
+                 end
+               end
+        unless uri.scheme == "http"
+          raise ArgumentError, "Unsupported URI scheme for #{uri.inspect}"
+        end
+        uri
+      end
+
+      class Calendar < Repo::Calendar
+        def body
+        end
+
+        def initialize(uri) #:nodoc:
+          @uri = Uri.uri_check(uri)
+        end
+
+        def name #:nodoc:
+          @uri.to_s
+        end
+
+        def displayed #:nodoc:
+          true
+        end
+
+        def each(klass, &block) #:nodoc:
+          unless iterator?
+            return Enumerable::Enumerator.new(self, :each, klass)
+          end
+
+          cals = Vpim::Icalendar.decode(encode)
+
+          cals.each do |cal|
+            cal.each(klass, &block)
+          end
+          self
+        end
+
+        def encode #:nodoc:
+          Net::HTTP.get_response(@uri) do |result|
+            accum = ""
+=begin
+better to let this pass up as an invalid encoding error
+            if result.code != "200"
+              raise StandardError,
+                "HTTP GET of #{@uri.to_s.inspect} failed with #{result.code} #{result.error_type}"
+            end
+=end
+            result.read_body do |chunk|
+              accum << chunk
+            end
+            return accum
+          end
+        end
+
+      end
+
+      def initialize(where)
+        @where = Uri.uri_check(where)
+      end
+
+      def each #:nodoc:
+        yield Calendar.new(@where)
+        self
+      end
+    end
   end
 end
 
