@@ -1,7 +1,5 @@
 =begin
-  $Id: time.rb,v 1.5 2005/02/02 02:55:59 sam Exp $
-
-  Copyright (C) 2005 Sam Roberts
+  Copyright (C) 2008 Sam Roberts
 
   This library is free software; you can redistribute it and/or modify it
   under the same terms as the ruby language itself, see the file COPYING for
@@ -23,7 +21,7 @@ class Time
 
     # Returns a new Time, +months+ later than this time. The day will be
     # rounded down if it is not valid for that month.
-    # 31 plus 1 month will be on Feb 28!
+    # Jan 31 plus 1 month will be on Feb 28!
     def plus_month(months)
       d = Date.new(year, month, day)
       d >>= months
