@@ -30,6 +30,18 @@ module Vpim
         @elements = inner
       end
 
+      # TODO - derive everything from Icalendar::Component to get rid of this kind of stuff?
+      def fields #:nodoc:
+        f = properties.to_a
+        last = f.pop
+        f.push @elements
+        f.push last
+      end
+
+      def properties #:nodoc:
+        @properties
+      end
+
       # Create a Vjournal component.
       def self.create(fields=[])
         di = DirectoryInfo.create([], 'VJOURNAL')
