@@ -1,7 +1,7 @@
-#!/usr/bin/ruby -w
-# $Id: ab-query.rb,v 1.5 2004/03/21 15:07:41 sam Exp $
+#!/usr/bin/env ruby
 
-$:.unshift File.dirname($0)
+$-w = true
+$:.unshift File.dirname($0) + '/../lib'
 
 require 'osx-wrappers'
 
