@@ -1,4 +1,4 @@
-#!/opt/local/bin/ruby -w
+#!/usr/bin/env ruby
 
 require 'vpim/vcard'
 require 'vpim/icalendar'
@@ -14,7 +14,7 @@ Vpim::Vcard.decode($in).each do |card|
       card.birthday,
       "Birthday for #{card['fn'].strip}"
       )
-    STDERR.puts "#{card['fn']} -> bday #{cal.events.last.dtstart}"
+    $stderr.puts "#{card['fn']} -> bday #{cal.events.last.dtstart}"
   end
 end
 
