@@ -1,5 +1,4 @@
-#!/usr/bin/ruby -w
-# $Id: vcf-to-mutt.rb,v 1.1 2004/12/04 23:12:18 sam Exp $
+#!/usr/bin/env ruby
 #
 # For a query command, mutt expects output of the form:
 #
@@ -13,7 +12,9 @@
 # NICKNAME shouldn't have spaces, and EMAIL can be either "user@example.com",
 # "<user@example.com>", or "User <user@example.com>".
 
-$:.unshift File.dirname($0)
+$-w = true
+$:.unshift File.dirname($0) + '/../lib'
+
 
 require 'getoptlong'
 require 'vpim/vcard'
