@@ -7,7 +7,7 @@ $-w = true
 $:.unshift File.dirname(__FILE__) + "/../lib"
 
 
-pp [__LINE__, $:, $"]
+#pp [__LINE__, $:, $"]
 
 require 'test/unit'
 
